/**
 * @since 1.0.0
 */
import type { DynamoDBClientConfig } from "@aws-sdk/client-dynamodb";
import type { BatchExecuteStatementCommandInput, BatchExecuteStatementCommandOutput, BatchGetCommandInput, BatchGetCommandOutput, BatchWriteCommandInput, BatchWriteCommandOutput, DeleteCommandInput, DeleteCommandOutput, DynamoDBDocumentClient, ExecuteStatementCommandInput, ExecuteStatementCommandOutput, ExecuteTransactionCommandInput, ExecuteTransactionCommandOutput, GetCommandInput, GetCommandOutput, PutCommandInput, PutCommandOutput, QueryCommandInput, QueryCommandOutput, ScanCommandInput, ScanCommandOutput, TransactGetCommandInput, TransactGetCommandOutput, TransactWriteCommandInput, TransactWriteCommandOutput, TranslateConfig, UpdateCommandInput, UpdateCommandOutput } from "@aws-sdk/lib-dynamodb";
import type { ConditionalCheckFailedError, DuplicateItemError, IdempotentParameterMismatchError, InternalServerError, InvalidEndpointError, ItemCollectionSizeLimitExceededError, ProvisionedThroughputExceededError, RequestLimitExceededError, ResourceNotFoundError, SdkError, TransactionCanceledError, TransactionConflictError, TransactionInProgressError } from "@effect-aws/client-dynamodb";
import { type HttpHandlerOptions } from "@effect-aws/commons";
import { Effect, Layer } from "effect";
import * as Instance from "./DynamoDBDocumentClientInstance.js";
interface DynamoDBDocumentService$ {
    readonly _: unique symbol;
    /**
     * @see {@link BatchExecuteStatementCommand}
     */
    batchExecuteStatement(args: BatchExecuteStatementCommandInput, options?: HttpHandlerOptions): Effect.Effect<BatchExecuteStatementCommandOutput, SdkError | InternalServerError | RequestLimitExceededError>;
    /**
     * @see {@link BatchGetCommand}
     */
    batchGet(args: BatchGetCommandInput, options?: HttpHandlerOptions): Effect.Effect<BatchGetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link BatchWriteCommand}
     */
    batchWrite(args: BatchWriteCommandInput, options?: HttpHandlerOptions): Effect.Effect<BatchWriteCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link DeleteCommand}
     */
    delete(args: DeleteCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link ExecuteStatementCommand}
     */
    executeStatement(args: ExecuteStatementCommandInput, options?: HttpHandlerOptions): Effect.Effect<ExecuteStatementCommandOutput, SdkError | ConditionalCheckFailedError | DuplicateItemError | InternalServerError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link ExecuteTransactionCommand}
     */
    executeTransaction(args: ExecuteTransactionCommandInput, options?: HttpHandlerOptions): Effect.Effect<ExecuteTransactionCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link GetCommand}
     */
    get(args: GetCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link PutCommand}
     */
    put(args: PutCommandInput, options?: HttpHandlerOptions): Effect.Effect<PutCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
    /**
     * @see {@link QueryCommand}
     */
    query(args: QueryCommandInput, options?: HttpHandlerOptions): Effect.Effect<QueryCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link ScanCommand}
     */
    scan(args: ScanCommandInput, options?: HttpHandlerOptions): Effect.Effect<ScanCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError>;
    /**
     * @see {@link TransactGetCommand}
     */
    transactGet(args: TransactGetCommandInput, options?: HttpHandlerOptions): Effect.Effect<TransactGetCommandOutput, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError>;
    /**
     * @see {@link TransactWriteCommand}
     */
    transactWrite(args: TransactWriteCommandInput, options?: HttpHandlerOptions): Effect.Effect<TransactWriteCommandOutput, SdkError | IdempotentParameterMismatchError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError>;
    /**
     * @see {@link UpdateCommand}
     */
    update(args: UpdateCommandInput, options?: HttpHandlerOptions): Effect.Effect<UpdateCommandOutput, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeDynamoDBDocumentService: Effect.Effect<DynamoDBDocumentService$, never, Instance.DynamoDBDocumentClientInstance>;
declare const DynamoDBDocumentService_base: import("effect/Context").TagClass<DynamoDBDocumentService, "@effect-aws/lib-dynamodb/DynamoDBDocumentService", DynamoDBDocumentService$> & {
    readonly _: Effect.Effect<DynamoDBDocumentService$["_"], never, DynamoDBDocumentService>;
    batchExecuteStatement: (args: BatchExecuteStatementCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<BatchExecuteStatementCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError, DynamoDBDocumentService>;
    batchGet: (args: BatchGetCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<BatchGetCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError, DynamoDBDocumentService>;
    batchWrite: (args: BatchWriteCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<BatchWriteCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError | ItemCollectionSizeLimitExceededError, DynamoDBDocumentService>;
    delete: (args: DeleteCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<DeleteCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError | ItemCollectionSizeLimitExceededError | ConditionalCheckFailedError | TransactionConflictError, DynamoDBDocumentService>;
    executeStatement: (args: ExecuteStatementCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ExecuteStatementCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | ProvisionedThroughputExceededError | ResourceNotFoundError | ItemCollectionSizeLimitExceededError | ConditionalCheckFailedError | TransactionConflictError | DuplicateItemError, DynamoDBDocumentService>;
    executeTransaction: (args: ExecuteTransactionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ExecuteTransactionCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | ProvisionedThroughputExceededError | ResourceNotFoundError | IdempotentParameterMismatchError | TransactionCanceledError | TransactionInProgressError, DynamoDBDocumentService>;
    get: (args: GetCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError, DynamoDBDocumentService>;
    put: (args: PutCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<PutCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError | ItemCollectionSizeLimitExceededError | ConditionalCheckFailedError | TransactionConflictError, DynamoDBDocumentService>;
    query: (args: QueryCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<QueryCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError, DynamoDBDocumentService>;
    scan: (args: ScanCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ScanCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError, DynamoDBDocumentService>;
    transactGet: (args: TransactGetCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<TransactGetCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError | TransactionCanceledError, DynamoDBDocumentService>;
    transactWrite: (args: TransactWriteCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<TransactWriteCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError | IdempotentParameterMismatchError | TransactionCanceledError | TransactionInProgressError, DynamoDBDocumentService>;
    update: (args: UpdateCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<UpdateCommandOutput, import("@effect-aws/commons").SdkError | InternalServerError | RequestLimitExceededError | InvalidEndpointError | ProvisionedThroughputExceededError | ResourceNotFoundError | ItemCollectionSizeLimitExceededError | ConditionalCheckFailedError | TransactionConflictError, DynamoDBDocumentService>;
} & {
    use: <X>(body: (_: DynamoDBDocumentService$) => X) => X extends Effect.Effect<infer A, infer E, infer R> ? Effect.Effect<A, E, DynamoDBDocumentService | R> : Effect.Effect<X, never, DynamoDBDocumentService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class DynamoDBDocumentService extends DynamoDBDocumentService_base {
    static readonly defaultLayer: Layer.Layer<DynamoDBDocumentService, never, never>;
    static readonly layer: (config: DynamoDBDocumentService.Config) => Layer.Layer<DynamoDBDocumentService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: DynamoDBClientConfig) => DynamoDBDocumentClient) => Layer.Layer<DynamoDBDocumentService, never, never>;
}
/**
 * @since 1.0.0
 */
export declare namespace DynamoDBDocumentService {
    /**
     * @since 1.0.0
     */
    type Config = TranslateConfig;
}
export {};
//# sourceMappingURL=DynamoDBDocumentService.d.ts.map